@@ -25,9 +25,9 @@
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 0.1.1
+// Version   : release 0.1.2
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 11 September 2007, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 13 September 2007, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -50,7 +50,7 @@
 #define MN3 4
 #define NXM 308
 #define NYM 308
-#define DIME 2003
+#define DIME 1003
 #define ITMAX 10000000
 #define POISSONITMAX 1500
 #define SMALL 1.e-5
@@ -66,13 +66,14 @@
 #define MESHFORMAT 1 // output file in Mesh format
 
 // definition of the material reference table
-#define NOAMTIA 4   // Number Of All Material Taken Into Account (excluding SiO2)
+#define NOAMTIA 5   // Number Of All Material Taken Into Account (excluding SiO2)
 // ********************
 #define iSIO2 -1      // reference number to Silicon Oxide
 #define SILICON 0    // reference number to Silicon
 #define GAAS 1       // reference number to GaAs
 #define GERMANIUM 2  // reference number to Germanium
 #define INSB 3       // reference number to InSb
+#define ALSB 4       // reference number to AlSb
 // ********************
 
 #define NUMSIO2 2 // maximum number of SiO2 interfaces
@@ -115,13 +116,12 @@ real HHM[NOAMTIA+1][3];
 real HM[NOAMTIA+1][3];
 real GM[NOAMTIA+1];
 real SWK[NOAMTIA+1][3][14][DIME+1];
-real P[NPMAX+1][7],EC[3];
+real P[NPMAX+1][7];
 real KX,KY,KZ,X,Y;
 real TS,EPP,DDmax;
 real EDGE[4][NXM+NYM+1][4];
 real CIMP,QD2,TAUW;
 real EPSRSIO2;
-real DG[NXM+1][NYM+1],DL[NXM+1][NYM+1];
 real bufx2d[NXM+1][NYM+1];
 real bufy2d[NXM+1][NYM+1];
 real ux2d[NXM+1][NYM+1][MN3+1];
@@ -233,7 +233,7 @@ Report bugs to sellier@dmi.unict.it or archimedes@southnovel.eu\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.1.1\n");
+      printf("archimedes - GNU archimedes 0.1.2\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -267,6 +267,7 @@ For more information about these matters, see the file named COPYING.\n",
      NOVALLEY[GERMANIUM]=1;
      NOVALLEY[GAAS]=2;
      NOVALLEY[INSB]=2;
+     NOVALLEY[ALSB]=2;
 // Dielectric constant for Silicon Oxide SiO2
      EPSRSIO2=17.0*EPS0;
 // Dielectric constant for Semiconducting materials
@@ -274,9 +275,11 @@ For more information about these matters, see the file named COPYING.\n",
      EPSR[GERMANIUM]=16.2*EPS0;
      EPSR[GAAS]=12.90*EPS0;
      EPSR[INSB]=17.65*EPS0;
+     EPSR[ALSB]=12.04*EPS0;
 // III-V semiconductor compounds high frequency dieletric constant
      EPF[GAAS]=10.92;
      EPF[INSB]=15.68;
+     EPF[ALSB]=9.88;
      int ii;
      for(ii=0;ii<NOAMTIA;ii++){
        int i;
@@ -298,6 +301,7 @@ For more information about these matters, see the file named COPYING.\n",
 // III-V semiconductor compounds optical phonon scattering energy (eV)
      HWO[GAAS][0]=0.03536;
      HWO[INSB][0]=0.0282;
+     HWO[ALSB][0]=0.0360;
 // Silicon optical coupling constants (eV/m)
      DTK[SILICON][0]=0.05e11;
      DTK[SILICON][1]=0.08e11;
@@ -310,6 +314,7 @@ For more information about these matters, see the file named COPYING.\n",
 // III-V semiconductor compounds optical coupling constant (eV/m)
      DTK[GAAS][0]=1.11e11;
      DTK[INSB][0]=0.47e11;
+     DTK[ALSB][0]=0.55e11;
 // Silicon optical phonon Z-factor
      ZF[SILICON][0]=1.;
      ZF[SILICON][1]=1.;
@@ -322,6 +327,7 @@ For more information about these matters, see the file named COPYING.\n",
 // III-V semiconductor compounds optical phonon Z-factor
      ZF[GAAS][0]=1.;
      ZF[INSB][0]=1.;
+     ZF[ALSB][0]=1.;
 // Silicon Crystal Density (Kg/m^3)
      RHO[SILICON]=2330.;
 // Germanium Crystal Density (Kg/m^3)
@@ -329,6 +335,7 @@ For more information about these matters, see the file named COPYING.\n",
 // III-V semiconductor compounds Crystal Density (Kg/m^3)
      RHO[GAAS]=5360.;
      RHO[INSB]=5790.;
+     RHO[ALSB]=4288.;
 // Silicon acoustic deformation potential (Joule)
      DA[SILICON]=9.*1.60217733e-19;
 // Germanium acoustic deformation potential (Joule)
@@ -336,6 +343,7 @@ For more information about these matters, see the file named COPYING.\n",
 // III-V semiconductor compounds acoustic deformation potential (Joule)
      DA[GAAS]=7.*1.60217733e-19;
      DA[INSB]=5.96*1.60217733e-19;
+     DA[ALSB]=4.6*1.60217733e-19;
 // Silicon longitudinal sound velocity (m/sec)
      UL[SILICON]=9040.;
 // Germanium longitudinal sound velocity (m/sec)
@@ -343,16 +351,7 @@ For more information about these matters, see the file named COPYING.\n",
 // III-V semiconductor compounds longitudinal sound velocity (m/sec)
      UL[GAAS]=5240.;
      UL[INSB]=4060.;
-// III-V Semiconductor materials energy gap
-     EG[SILICON]=1.21-3.333e-4*TL;
-     printf("EG[SILICON]      = %g\n",EG[SILICON]);
-     EG[GERMANIUM]=0.747-3.587e-4*TL;
-     printf("EG[GERMANIUM]    = %g\n",EG[GERMANIUM]);
-     EG[GAAS]=1.54-4.036e-4*TL;//0.32;???
-     printf("EG[GAAS]         = %g\n",EG[GAAS]);
-     EG[INSB]=0.2446-2.153e-4*TL;//0.174;???
-     printf("EG[INSB]         = %g\n",EG[INSB]);
-     printf("\n");
+     UL[ALSB]=4600.;
 // Silicon minimum energy
      EMIN[SILICON][1]=0.0;
 // Germanium minimum energy
@@ -360,9 +359,11 @@ For more information about these matters, see the file named COPYING.\n",
 // III-V semiconductor compounds minimum energy of GAMMA-valley
      EMIN[GAAS][1]=0.0;
      EMIN[INSB][1]=0.0;
+     EMIN[ALSB][1]=0.507;
 // III-V semiconductor compounds minimum energy of L-valley (eV)
      EMIN[GAAS][2]=0.323;
      EMIN[INSB][2]=1.038;
+     EMIN[ALSB][2]=0.292;
 // Definition of effective mass for all materials in all valleys
      MSTAR[SILICON][1]=0.32;
      MSTAR[GAAS][1]=0.067; // Gamma-valley
@@ -370,23 +371,12 @@ For more information about these matters, see the file named COPYING.\n",
      MSTAR[GERMANIUM][1]=0.22;
      MSTAR[INSB][1]=0.013;
      MSTAR[INSB][2]=0.442;
+     MSTAR[ALSB][1]=0.14;
+     MSTAR[ALSB][2]=0.442;
 // non-parabolicity coefficient for Silicon
      alphaK[SILICON][1]=0.5;
 // non-parabolicity coefficient for Germanium
      alphaK[GERMANIUM][1]=0.65;
-// non-parabolicity coefficient for GaAs in the GAMMA-valley
-     alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/EG[GAAS];//0.611;
-     printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
-// non-parabolicity coefficient for GaAs in the L-valley
-     alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/EG[GAAS];//0.242;
-     printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
-// non-parabolicity coefficient for InSb in the GAMMA-valley
-     alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/EG[INSB];//5.59;
-     printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
-// non-parabolicity coefficient for InSb in the L-valley
-     alphaK[INSB][2]=pow(1.-MSTAR[INSB][2],2.)/EG[INSB];//1.789;
-     printf("alphaK_L[InSb]     = %g\n",alphaK[INSB][2]);
-     printf("\n");
 // ======================================================
 // ======================================================
 
@@ -401,6 +391,40 @@ For more information about these matters, see the file named COPYING.\n",
 // ===========================================================
      Read_Input_File();
 
+// III-V Semiconductor materials energy gap (depending on the lattice temperature)
+     printf("\n");
+     EG[SILICON]=1.21-3.333e-4*TL;
+     printf("EG[SILICON]      = %g\n",EG[SILICON]);
+     EG[GERMANIUM]=0.747-3.587e-4*TL;
+     printf("EG[GERMANIUM]    = %g\n",EG[GERMANIUM]);
+     EG[GAAS]=1.54-4.036e-4*TL;
+     printf("EG[GAAS]         = %g\n",EG[GAAS]);
+     EG[INSB]=0.2446-2.153e-4*TL;
+     printf("EG[INSB]         = %g\n",EG[INSB]);
+     EG[ALSB]=1.696-2.20e-4*TL;
+     printf("EG[ALSB]         = %g\n",EG[ALSB]);
+     printf("\n");
+
+// all the following non-parabolicity coefficients depend on lattice temperature
+// non-parabolicity coefficient for GaAs in the GAMMA-valley
+     alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/(EG[GAAS]+EMIN[GAAS][1]);//expected value = 0.611
+     printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
+// non-parabolicity coefficient for GaAs in the L-valley
+     alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/(EG[GAAS]+EMIN[GAAS][2]);//expected value = 0.242;
+     printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
+// non-parabolicity coefficient for InSb in the GAMMA-valley
+     alphaK[INSB][1]=pow(1.-MSTAR[INSB][1],2.)/(EG[INSB]+EMIN[INSB][1]);//5.59;
+     printf("alphaK_gamma[InSb] = %g\n",alphaK[INSB][1]);
+// non-parabolicity coefficient for InSb in the L-valley
+     alphaK[INSB][2]=pow(1.-MSTAR[INSB][2],2.)/(EG[INSB]+EMIN[INSB][2]);//1.789;
+     printf("alphaK_L[InSb]     = %g\n",alphaK[INSB][2]);
+// non-parabolicity coefficient for AlSb in the GAMMA-valley
+     alphaK[ALSB][1]=pow(1.-MSTAR[ALSB][1],2.)/(EG[ALSB]+EMIN[ALSB][1]);//0.321;
+     printf("alphaK_gamma[AlSb] = %g\n",alphaK[ALSB][1]);
+// non-parabolicity coefficient for AlSb in the L-valley
+     alphaK[ALSB][2]=pow(1.-MSTAR[ALSB][2],2.)/(EG[ALSB]+EMIN[ALSB][2]);//0.135;
+     printf("alphaK_L[AlSb]     = %g\n",alphaK[ALSB][2]);
+
 // Closure of the input file
 // =========================
      fclose(fp);
@@ -428,6 +452,7 @@ For more information about these matters, see the file named COPYING.\n",
       for(i=0;i<NOAMTIA;i++) MCparameters(i);
       MCdevice_config();
      }
+     printf("/n");
 // HERE IS THE SIMULATION
 // ======================
      for(c=1;c<=ITMAX;c++) updating(Model_Number);
