@@ -1,5 +1,5 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.0.9.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
+/* readinputfile.h -- This file is part of Archimedes release 0.1.2
+   Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
@@ -10,7 +10,7 @@
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 9, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -19,27 +19,25 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-   USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 
 // ######################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 07 september 2007, Siracusa, J.M.Sellier
+// Last modif. : 12 september 2007, Catania, J.M.Sellier
 // ######################################################
 
 // Read the geometrical and physical description of the device.
 // The input file is interpreted as in a script language.
 // For the syntax of the commands of this language see
-// the manual GNU Archimedes release 0.0.9
+// the manual GNU Archimedes release 0.1.2
 
 void
 Read_Input_File(void)
 {
- char s[80];
+ char s[180];
  double num,num0;
- double dum;
  int ini,fin;
  int i,j;
  int LXflag=0, LYflag=0;
@@ -51,13 +49,11 @@ Read_Input_File(void)
 // the following values.
 // ============================
  Model_Number=MCE; // here we choose the model
-// Material=SILICON; // MESFET made of Silicon
  nx=50; // default # of cells in x-direction
  ny=50; // default # of cells in y-direction
  TF=5.0e-12; // Default Final Time in seconds
  DT=0.001e-12; // Default constant time step
  TAUW=0.4e-12; // Default Energy relaxation time
-// mstar=MSTAR[SILICON][1]; // coefficient of the Si elettronic effective mass
  msh=mstarHSILICON; // coefficient of the Si heavy hole effective mass
  FARADAYFLAG=0; // no evolution of magnetic field taken into account as default (B = 0 or const.)
 // standard doping concentration
@@ -67,7 +63,8 @@ Read_Input_File(void)
       h2d[i][j][1]=N_H[i][j]=NI;
       u2d[i][j][2]=u2d[i][j][3]=0.;
       h2d[i][j][2]=h2d[i][j][3]=0.;
-      i_dom[i][j]=0;
+      i_dom[i][j]=SILICON; // Silicon everywhere as default
+      B[i][j]=0.; // no magnetic field as default
    }
  CIMP=1.e20; // Impurity concentration
  TL=300.; // Lattice temperature in Kelvin
@@ -113,20 +110,32 @@ Processing the input file\n\
       exit(0);
     }
     fscanf(fp,"%s",s);
-    if(strcmp(s,"SILICON")==0)        type=SILICON;
-    else if(strcmp(s,"GAAS")==0)      type=GAAS;
-    else if(strcmp(s,"GERMANIUM")==0) type=GERMANIUM;
+    if(strcmp(s,"SILICON")==0){
+        type=SILICON;
+        msh=mstarHSILICON;
+    }
+    else if(strcmp(s,"GAAS")==0){
+        type=GAAS;
+        msh=mstarHGAAS;
+    }
+    else if(strcmp(s,"GERMANIUM")==0){
+        type=GERMANIUM;
+        msh=mstarHGERMANIUM;
+    }
+    else if(strcmp(s,"INSB")==0) type=INSB;
+    else if(strcmp(s,"ALSB")==0) type=ALSB;
     else{
       printf("%s : unknown specified material!\n",progname);
       exit(0);
     }
-    printf("MATERIAL %s X=[%g,%g] Y=[%g,%g] ---> Ok\n",s,xi,xf,yi,yf);
-    for(i=1;i<=nx+4;i++)
-      for(j=1;j<=ny+4;j++)
+    for(i=0;i<=nx+4;i++)
+      for(j=0;j<=ny+4;j++){
         if((i-0.5)*dx>=xi && (i-1.5)*dx<=xf
          &&(j-0.5)*dy>=yi && (j-1.5)*dy<=yf){
            i_dom[i][j]=type;
         }
+      }
+    printf("MATERIAL %s X=[%g,%g] Y=[%g,%g] ---> Ok\n",s,xi,xf,yi,yf);
   }
 // here we choose the charge particle transport simulated
   else if(strcmp(s,"TRANSPORT")==0){
@@ -302,7 +311,7 @@ Processing the input file\n\
     FILE *dp;
     FILE *pp;
     FILE *ep;
-    float dum,dum0,dum1;
+    double dum,dum0,dum1;
 // Open the initial electron density file
     dp=fopen("density_start.xyz","r");
 // File Control, just in case the file does not exist...
